@@ -306,7 +306,7 @@ type issueWorklogRequest struct {
 
 // AddIssueWorklog adds worklog to an issue using POST /issue/{key}/worklog endpoint.
 // Leave param `started` empty to use the server's current datetime as start date.
-func (c *Client) AddIssueWorklog(key, started, timeSpent, comment string) error {
+func (c *Client) AddIssueWorklog(key, started, timeSpent, comment, newEstimate string) error {
 	worklogReq := issueWorklogRequest{
 		TimeSpent: timeSpent,
 		Comment:   md.ToJiraMD(comment),
@@ -320,6 +320,9 @@ func (c *Client) AddIssueWorklog(key, started, timeSpent, comment string) error
 	}
 
 	path := fmt.Sprintf("/issue/%s/worklog", key)
+	if newEstimate != "" {
+		path = fmt.Sprintf("%s?adjustEstimate=new&newEstimate=%s", path, newEstimate)
+	}
 	res, err := c.PostV2(context.Background(), path, body, Header{
 		"Accept":       "application/json",
 		"Content-Type": "application/json",
